@@ -1,26 +1,26 @@
-import ee
-import os
-import sys
 import logging
-import requests
-import warnings
+import os
 import subprocess
-import numpy as np
-from io import BytesIO
-import matplotlib as mpl
-import matplotlib.pyplot as plt
-import matplotlib.patches as patches
-from matplotlib import font_manager as mfonts
-from matplotlib import cm, colors
+import sys
+import warnings
 from collections.abc import Iterable
+from io import BytesIO
 
+import ee
+import matplotlib as mpl
+import matplotlib.patches as patches
+import matplotlib.pyplot as plt
+import numpy as np
+import requests
+from matplotlib import cm, colors
+from matplotlib import font_manager as mfonts
 
 try:
 
-    from PIL import Image
     import cartopy.crs as ccrs
     from cartopy.mpl.geoaxes import GeoAxes, GeoAxesSubplot
     from cartopy.mpl.gridliner import LATITUDE_FORMATTER, LONGITUDE_FORMATTER
+    from PIL import Image
 
 except ImportError:
 
@@ -166,7 +166,7 @@ def add_layer(
     args:
         ee_object (ee.Image | ee.FeatureCollection): Earth Engine image result to plot.
         ax (cartopy.mpl.geoaxes.GeoAxesSubplot | cartopy.mpl.geoaxes.GeoAxes): required cartopy GeoAxesSubplot object to add image overlay to
-        dims (list | tuple | int, optional): dimensions to request earth engine result as [WIDTH,HEIGHT]. If only one number is passed, it is used as the maximum, and the other dimension is computed by proportional scaling. Default None and infers dimesions
+        dims (list | tuple | int, optional): dimensions to request earth engine result as [WIDTH,HEIGHT]. If only one number is passed, it is used as the maximum, and the other dimension is computed by proportional scaling. Default None and infers dimensions
         region (list | tuple, optional): geospatial region of the image to render in format [E,S,W,N]. By default, the whole image
         cmap (str, optional): string specifying matplotlib colormap to colorize image. If cmap is specified visParams cannot contain 'palette' key
         vis_params (dict, optional): visualization parameters as a dictionary. See https://developers.google.com/earth-engine/image_visualization for options
@@ -205,9 +205,9 @@ def add_layer(
 
     if region is not None:
         map_region = ee.Geometry.Rectangle(region).getInfo()["coordinates"]
-        view_extent = (region[0], region[2], region[1], region[3])
+        view_extent = (region[2], region[0], region[1], region[3])
     else:
-        map_region = ee_object.geometry(100).bounds().getInfo()["coordinates"]
+        map_region = ee_object.geometry(100).bounds(1).getInfo()["coordinates"]
         # get the image bounds
         x, y = list(zip(*map_region[0]))
         view_extent = [min(x), max(x), min(y), max(y)]
@@ -222,8 +222,7 @@ def add_layer(
         )
 
     args = {"format": "png", "crs": "EPSG:4326"}
-    if region:
-        args["region"] = map_region
+    args["region"] = map_region
     if dims:
         args["dimensions"] = dims
 
@@ -415,12 +414,26 @@ def add_colorbar(
                 'cmap keyword or "palette" key in visParams must be provided'
             )
 
+    tick_font_size = None
+    if "tick_font_size" in kwargs:
+        tick_font_size = kwargs.pop("tick_font_size")
+
+    label_font_size = None
+    if "label_font_size" in kwargs:
+        label_font_size = kwargs.pop("label_font_size")
+
     cb = mpl.colorbar.ColorbarBase(cax, norm=norm, alpha=alpha, cmap=cmap, **kwargs)
 
     if "bands" in vis_keys:
         cb.set_label(vis_params["bands"])
     elif label is not None:
-        cb.set_label(label)
+        if label_font_size is not None:
+            cb.set_label(label, fontsize=label_font_size)
+        else:
+            cb.set_label(label)
+
+    if tick_font_size is not None:
+        cb.ax.tick_params(labelsize=tick_font_size)
 
     return
 
@@ -690,9 +703,9 @@ def add_scale_bar(
     Args:
         ax (cartopy.mpl.geoaxes.GeoAxesSubplot | cartopy.mpl.geoaxes.GeoAxes): required cartopy GeoAxesSubplot object.
         metric_distance (int | float, optional): length in meters of each region of the scale bar. Default to 4.
-        unit (str, optinal): scale bar distance unit. Default to "km"
+        unit (str, optional): scale bar distance unit. Default to "km"
         at_x (float, optional): target axes X coordinates (0..1) of box (= left, right). Default to (0.05, 0.2).
-        at_y (float, optional): axes Y coordinates (0..1) of box (= lower, upper). Deafult to (0.08, 0.11).
+        at_y (float, optional): axes Y coordinates (0..1) of box (= lower, upper). Default to (0.08, 0.11).
         max_stripes (int, optional): typical/maximum number of black+white regions. Default to 5.
         ytick_label_margins (float, optional): Location of distance labels on the Y axis. Default to 0.25.
         fontsize (int, optional): scale bar text size. Default to 8.
@@ -710,7 +723,7 @@ def add_scale_bar(
     # Auxiliary functions
 
     def _crs_coord_project(crs_target, xcoords, ycoords, crs_source):
-        """ metric coordinates (x, y) from cartopy.crs_source"""
+        """metric coordinates (x, y) from cartopy.crs_source"""
 
         axes_coords = crs_target.transform_points(crs_source, xcoords, ycoords)
 
@@ -956,7 +969,7 @@ def add_scale_bar_lite(
     sby = y0 + (y1 - y0) * xy[1]
 
     # Calculate a scale bar length if none has been given
-    # (Theres probably a more pythonic way of rounding the number but this works)
+    # (There's probably a more pythonic way of rounding the number but this works)
     if not length:
         length = (x1 - x0) / 5000  # in km
         ndim = int(np.floor(np.log10(length)))  # number of digits in number
