@@ -16,11 +16,13 @@ To execute all Jupyter notebooks in a folder recursively:
 
 
 import os
-import pkg_resources
 import shutil
 import urllib.request
 from collections import deque
 from pathlib import Path
+
+import pkg_resources
+
 from .common import *
 
 
@@ -340,7 +342,6 @@ def js_to_python(in_file, out_file=None, use_qgis=True, github_repo=None):
             lines = check_map_functions(lines)
 
             for index, line in enumerate(lines):
-
                 if ("/* color" in line) and ("*/" in line):
                     line = (
                         line[: line.index("/*")].lstrip()
@@ -352,7 +353,14 @@ def js_to_python(in_file, out_file=None, use_qgis=True, github_repo=None):
                     or ("=function" in line)
                     or line.strip().startswith("function")
                 ):
-                    bracket_index = line.index("{")
+                    try:
+                        bracket_index = line.index("{")
+                    except Exception as e:
+                        print(
+                            f"An error occurred when processing {in_file}. The closing curly bracket could not be found in Line {index+1}: {line}. Please reformat the function definition and make sure that both the opening and closing curly brackets apprear on the same line as the function keyword. "
+                        )
+                        return
+
                     (
                         matching_line_index,
                         matching_char_index,
