@@ -1,14 +1,15 @@
 """ This module extends the folium Map class. It is designed to be used in Google Colab, as Google Colab currently does not support ipyleaflet.
 """
 import os
+
 import ee
 import folium
 from folium import plugins
+
 from .common import *
 from .conversion import *
 from .legends import builtin_legends
 
-
 # More WMS basemaps can be found at https://viewer.nationalmap.gov/services/
 ee_basemaps = {
     "ROADMAP": folium.TileLayer(
@@ -155,8 +156,8 @@ class Map(folium.Map):
             ee_initialize()
 
         # Default map center location and zoom level
-        latlon = [40, -100]
-        zoom = 4
+        latlon = [20, 0]
+        zoom = 2
 
         # Interchangeable parameters between ipyleaflet and folium
         if "center" in kwargs.keys():
@@ -274,7 +275,7 @@ class Map(folium.Map):
             and not isinstance(ee_object, ee.Feature)
             and not isinstance(ee_object, ee.Geometry)
         ):
-            err_str = "\n\nThe image argument in 'addLayer' function must be an instace of one of ee.Image, ee.Geometry, ee.Feature or ee.FeatureCollection."
+            err_str = "\n\nThe image argument in 'addLayer' function must be an instance of one of ee.Image, ee.Geometry, ee.Feature or ee.FeatureCollection."
             raise AttributeError(err_str)
 
         if (
@@ -334,7 +335,7 @@ class Map(folium.Map):
     addLayer = add_layer
 
     def _repr_mimebundle_(self, include, exclude, **kwargs):
-        """Adds Layer control to the map. Referece: https://ipython.readthedocs.io/en/stable/config/integrating.html#MyObject._repr_mimebundle_
+        """Adds Layer control to the map. Reference: https://ipython.readthedocs.io/en/stable/config/integrating.html#MyObject._repr_mimebundle_
 
         Args:
             include ([type]): [description]
@@ -660,7 +661,7 @@ class Map(folium.Map):
         """
 
         import pkg_resources
-        from branca.element import Template, MacroElement
+        from branca.element import MacroElement, Template
 
         pkg_dir = os.path.dirname(
             pkg_resources.resource_filename("geemap", "geemap.py")
@@ -674,7 +675,7 @@ class Map(folium.Map):
             if not isinstance(labels, list):
                 raise ValueError("The legend labels must be a list.")
         else:
-            labels = ["One", "Two", "Three", "Four", "ect"]
+            labels = ["One", "Two", "Three", "Four", "etc"]
 
         if colors is not None:
             if not isinstance(colors, list):
@@ -805,6 +806,8 @@ class Map(folium.Map):
 
         self.add_child(colormap)
 
+    add_colorbar_branca = add_colorbar
+
     def add_styled_vector(
         self, ee_object, column, palette, layer_name="Untitled", **kwargs
     ):
@@ -849,6 +852,7 @@ class Map(folium.Map):
             FileNotFoundError: The provided GeoJSON file could not be found.
         """
         import json
+
         import requests
 
         try:
@@ -928,7 +932,7 @@ class Map(folium.Map):
 
         """
 
-        gdf = osm_to_geopandas(
+        gdf = osm_to_gdf(
             query, which_result=which_result, by_osmid=by_osmid, buffer_dist=buffer_dist
         )
         geojson = gdf.__geo_interface__
